#!/bin/csh
#
set echo
#
# --- extract 2-d fields from a single HYCOM archive file.
#
# --- output is netCDF.
# --- this is an example, customize it for your datafile needs.
#
setenv R GOMl0.08
setenv E expt_01.0
setenv T 72
#
touch regional.depth.a regional.depth.b
if (-z regional.depth.a) then
  /bin/rm regional.depth.a
  /bin/ln -s ../topo/depth_${R}_${T}.a regional.depth.a
endif
if (-z regional.depth.b) then
  /bin/rm regional.depth.b
  /bin/ln -s ../topo/depth_${R}_${T}.b regional.depth.b
endif
#
touch regional.grid.a regional.grid.b
if (-z regional.grid.a) then
  /bin/rm regional.grid.a
  /bin/ln -s ../topo/regional.grid.a .
endif
if (-z regional.grid.b) then
  /bin/rm regional.grid.b
  /bin/ln -s ../topo/regional.grid.b .
endif
#
# --- optional title and institution.
#
setenv CDF_TITLE	"HYCOM ${R}"
setenv CDF_INST 	"NOAA/AOML"
#
setenv DA ~/ARCHIVE/hycom/${R}/relax/010
setenv DN ~/ARCHIVE/hycom/${R}/relax/010
foreach y ( 0000 )
  setenv DA ~/ARCHIVE/hycom/${R}/relax/010
  setenv DN ~/ARCHIVE/hycom/${R}/relax/010
  foreach d ( 016 046 077 107 138 168 199 229 260 290 321 351 )
    foreach h ( 00 )
      setenv CDF051  ${DN}/topo.${y}_${d}_${h}_2d.nc
      setenv CDF021  ${DN}/sfcflx.${y}_${d}_${h}_2d.nc
      setenv CDF022  ${DN}/ice.${y}_${d}_${h}_2d.nc
      setenv CDF023  ${DN}/ssh.${y}_${d}_${h}_2d.nc
      setenv CDF024  ${DN}/barotp.${y}_${d}_${h}_2d.nc
      setenv CDF025  ${DN}/mxlayr.${y}_${d}_${h}_2d.nc
      setenv CDF026  ${DN}/tc.${y}_${d}_${h}_2d.nc
      setenv CDF027  ${DN}/dynht.${y}_${d}_${h}_2d.nc
      setenv CDF031  ${DN}/vel.${y}_${d}_${h}_layer1.nc
      setenv CDF032  ${DN}/intf.${y}_${d}_${h}_layer1.nc
      setenv CDF033  ${DN}/thknss.${y}_${d}_${h}_layer1.nc
      setenv CDF034  ${DN}/thermo.${y}_${d}_${h}_layer1.nc
      setenv CDF035  ${DN}/strmf.${y}_${d}_${h}_layer1.nc
      /bin/rm $CDF051
      /bin/rm $CDF021  $CDF022  $CDF023  $CDF024  $CDF025  $CDF026  $CDF027
      /bin/rm $CDF031  $CDF032  $CDF033  $CDF034  $CDF035
      ../../ALL/archive/src/archv2ncdf2d <<E-o-D
${DA}/relax.${y}_${d}_${h}.a
netCDF
 000	'iexpt ' = experiment number x10 (000=from archive file)
   0	'yrflag' = days in year flag (0=360J16,1=366J16,2=366J01,3-actual)
 271	'idm   ' = longitudinal array size
 193	'jdm   ' = latitudinal  array size
  26	'kdm   ' = number of layers
  25.0	'thbase' = reference density (sigma units)
   1	'smooth' = smooth fields before plotting (0=F,1=T)
   0	'mthin ' = mask thin layers from plots   (0=F,1=T)
   1	'iorign' = i-origin of plotted subregion
   1	'jorign' = j-origin of plotted subregion
   0	'idmp  ' = i-extent of plotted subregion (<=idm; 0 implies idm)
   0	'jdmp  ' = j-extent of plotted subregion (<=jdm; 0 implies jdm)
   0	'botio ' = bathymetry       I/O unit (0 no I/O)
   0	'flxio ' = surf. heat flux  I/O unit (0 no I/O)
   0	'empio ' = surf. evap-pcip  I/O unit (0 no I/O)
   0	'ttrio ' = surf. temp trend I/O unit (0 no I/O)
   0	'strio ' = surf. saln trend I/O unit (0 no I/O)
   0	'icvio ' = ice coverage     I/O unit (0 no I/O)
   0	'ithio ' = ice thickness    I/O unit (0 no I/O)
   0	'ictio ' = ice temperature  I/O unit (0 no I/O)
   0	'sshio ' = sea surf. height I/O unit (0 no I/O)
   0	'bsfio ' = baro. strmfn.    I/O unit (0 no I/O)
   0	'uvmio ' = mix. lay. u-vel. I/O unit (0 no I/O)
   0	'vvmio ' = mix. lay. v-vel. I/O unit (0 no I/O)
   0	'spmio ' = mix. lay. speed  I/O unit (0 no I/O)
   0	'bltio ' = bnd. lay. thick. I/O unit (0 no I/O)
   0	'mltio ' = mix. lay. thick. I/O unit (0 no I/O)
   0	'sstio ' = mix. lay. temp.  I/O unit (0 no I/O)
   0	'sssio ' = mix. lay. saln.  I/O unit (0 no I/O)
   0	'ssdio ' = mix. lay. dens.  I/O unit (0 no I/O)
   0    'h20io ' = 20C isoth. dep.  I/O unit (0 no I/O)
   0    'h26io ' = 26C isoth. dep.  I/O unit (0 no I/O)
   0    'ohcio ' = OHC              I/O unit (0 no I/O)
   0.0  'refz0 ' = dyn. ht. z reference level (0.0 no I/O)
   0.0  'refz1 ' = dyn. ht. at refz1 referenced to refz0 (0.0 no I/O)
   0.0  'refth0' = dyn. ht. theta reference level (0.0 no I/O)
   0.0  'refth1' = dyn. ht. at refth1 referenced to refth0 (0.0 no I/O)
   0    'dynhz ' = dyn. ht., z ref  I/O unit (0 no I/O)
   0    'dynhth' = dyn. ht., th ref I/O unit (0 no I/O)
   1	'kf    ' = first output layer (=0 end output; <0 label with layer #)
   1	'kl    ' = last  output layer
   0  	'uvlio ' = layer k   u-vel. I/O unit (0 no I/O)
   0	'vvlio ' = layer k   v-vel. I/O unit (0 no I/O)
   0	'splio ' = layer k   speed. I/O unit (0 no I/O)
   0    'infio ' = layer k   i.dep. I/O unit (0 no I/O)
   0	'thkio ' = layer k   thick. I/O unit (0 no I/O)
  34	'temio ' = layer k   temp   I/O unit (0 no I/O)
  34	'salio ' = layer k   saln.  I/O unit (0 no I/O)
   0	'tthio ' = layer k   dens,  I/O unit (0 no I/O)
   0	'sfnio ' = layer k  strmfn. I/O unit (0 no I/O)
   0	'kf    ' = first output layer (=0 end output; <0 label with layer #)
E-o-D
    end
  end
end
