#!/bin/csh
#
set echo
#
# --- interpolate to 3-d z-levels from a single HYCOM archive file.
# --- z-levels, via linear interpolation.
#
# --- output is netCDF.
# --- this is an example, customize it for your datafile needs.
#
setenv R GOMl0.08
setenv E expt_01.0
setenv T 72
#
touch regional.depth.a regional.depth.b
if (-z regional.depth.a) then
  /bin/rm regional.depth.a
  /bin/ln -s ../topo/depth_${R}_${T}.a regional.depth.a
endif
if (-z regional.depth.b) then
  /bin/rm regional.depth.b
  /bin/ln -s ../topo/depth_${R}_${T}.b regional.depth.b
endif
#
touch regional.grid.a regional.grid.b
if (-z regional.grid.a) then
  /bin/rm regional.grid.a
  /bin/ln -s ../topo/regional.grid.a .
endif
if (-z regional.grid.b) then
  /bin/rm regional.grid.b
  /bin/ln -s ../topo/regional.grid.b .
endif
#
# --- optional title and institution.
#
setenv CDF_TITLE	"HYCOM ${R}"
setenv CDF_INST 	"NOAA/AOML"
#
foreach y ( 2000 )
  setenv DA ~/ARCHIVE/hycom/${R}/${E}/${y}_archives
  setenv DN ~/ARCHIVE/hycom/${R}/${E}/${y}_netcdf
  if (! -e ${DN}) then
    /bin/mkdir ${DN}
  endif
  foreach d ( 001 )
    foreach h ( 12 )
      setenv CDF031  ${DN}/intf.${y}_${d}_${h}_3z.nc
      setenv CDF032  ${DN}/vel.${y}_${d}_${h}_3z.nc
      setenv CDF033  ${DN}/thermo.${y}_${d}_${h}_3z.nc
      setenv CDF034  ${DN}/ke.${y}_${d}_${h}_3z.nc
      /bin/rm $CDF031  $CDF032  $CDF033  $CDF034
      ../../ALL/archive/src/archv2ncdf3z <<E-o-D
${DA}/archv.${y}_${d}_${h}.a
netCDF
 000	'iexpt ' = experiment number x10 (000=from archive file)
   3	'yrflag' = days in year flag (0=360J16,1=366J16,2=366J01,3-actual)
 271	'idm   ' = longitudinal array size
 193	'jdm   ' = latitudinal  array size
  26	'kdm   ' = number of layers
  25.0	'thbase' = reference density (sigma units)
   1	'smooth' = smooth the layered fields (0=F,1=T)
   1	'iorign' = i-origin of plotted subregion
   1	'jorign' = j-origin of plotted subregion
   0	'idmp  ' = i-extent of plotted subregion (<=idm; 0 implies idm)
   0	'jdmp  ' = j-extent of plotted subregion (<=jdm; 0 implies jdm)
   1	'itype ' = interpolation type (0=sample,1=linear)
  42	'kz    ' = number of depths to sample
   0.0	'z     ' = sample depth  1
   3.0	'z     ' = sample depth  2
   6.0	'z     ' = sample depth  3
  10.0	'z     ' = sample depth  4
  15.0	'z     ' = sample depth  5
  20.0  'z     ' = sample depth  6
  25.0  'z     ' = sample depth  7
  30.0  'z     ' = sample depth  8
  35.0  'z     ' = sample depth  9
  40.0  'z     ' = sample depth 10
  45.0  'z     ' = sample depth 11
  50.0  'z     ' = sample depth 12
  60.0  'z     ' = sample depth 13
  70.0  'z     ' = sample depth 14
  80.0  'z     ' = sample depth 15
  90.0  'z     ' = sample depth 16
 100.0  'z     ' = sample depth 17
 110.0  'z     ' = sample depth 18
 120.0  'z     ' = sample depth 19
 130.0  'z     ' = sample depth 20
 140.0  'z     ' = sample depth 21
 150.0  'z     ' = sample depth 22
 160.0  'z     ' = sample depth 23
 170.0  'z     ' = sample depth 24
 180.0  'z     ' = sample depth 25
 190.0  'z     ' = sample depth 26
 200.0  'z     ' = sample depth 27
 220.0  'z     ' = sample depth 28
 240.0  'z     ' = sample depth 29
 260.0  'z     ' = sample depth 30
 280.0  'z     ' = sample depth 31
 300.0	'z     ' = sample depth 32
 350.0	'z     ' = sample depth 33
 400.0	'z     ' = sample depth 34
 450.0  'z     ' = sample depth 35
 500.0	'z     ' = sample depth 36
 550.0	'z     ' = sample depth 37
 600.0	'z     ' = sample depth 38
 650.0	'z     ' = sample depth 39
 700.0  'z     ' = sample depth 40
 750.0  'z     ' = sample depth 41
 800.0  'z     ' = sample depth 42
   0	'botio ' = bathymetry  I/O unit (0 no I/O)
   0	'mltio ' = mix.l.thk.  I/O unit (0 no I/O)
0.2     'tmljmp' = mix.l. temperature jump at base
0.05    'densml'
  31	'infio ' = intf. depth I/O unit (0 no I/O, <0 label with layer #)
  31	'wviio ' = intf. veloc I/O unit (0 no I/O)
  32	'wvlio ' = w-velocity  I/O unit (0 no I/O)
  32	'uvlio ' = u-velocity  I/O unit (0 no I/O)
  32	'vvlio ' = v-velocity  I/O unit (0 no I/O)
  32	'splio ' = speed       I/O unit (0 no I/O)
  33	'temio ' = temperature I/O unit (0 no I/O)
  33	'salio ' = salinity    I/O unit (0 no I/O)
  33	'tthio ' = density     I/O unit (0 no I/O)
  34    'keio  ' = KE          I/O unit (0 no I/O)
E-o-D
    end
  end
end
