#!/bin/csh
#PBS -N remap_restep
#PBS -A ocean-osse
#PBS -d .
#PBS -q bigmem
#PBS -o remap_restep.out
#PBS -e remap_restep.err
#PBS -l walltime=0:30:0
#PBS -l procs=1
#PBS -l vmem=2000M
#
set echo
set time=1
#
date
#
# --- remap the vertical discritization of nested archive files
#
# --- supports change of reference pressure, but resulting remapping
# --- may not be accurate

setenv P  ~/s4/hycom
setenv R  HAT20.08
#
setenv DI ${P}/${R}/expt_01.0/data/archv_fm
setenv D  ${P}/${R}/expt_02.0/data/archv_fm
setenv T  ${P}/${R}/topo
#
if (! -e ${D}) then
  /bin/mkdir ${D}
endif
#
cd ${DI}
#
touch regional.depth.a regional.depth.b
if (-z regional.depth.a) then
  /bin/rm regional.depth.a
  /bin/ln -s ${T}/regional.depth.a .
endif
if (-z regional.depth.b) then
  /bin/rm regional.depth.b
  /bin/ln -s ${T}/regional.depth.b .
endif
#
touch regional.grid.a regional.grid.b
if (-z regional.grid.a) then
  /bin/rm regional.grid.a
  /bin/ln -s ${T}/regional.grid.a .
endif
if (-z regional.grid.b) then
  /bin/rm regional.grid.b
  /bin/ln -s ${T}/regional.grid.b .
endif
#
foreach y ( 2009 )
  foreach d ( 240 )
    foreach h ( 00 )
      setenv ydh  ${y}_${d}_${h}
      if (-e ${DI}/archv.${ydh}.b) then
        touch   ${D}/archv.${ydh}.b
        /bin/rm ${D}/archv.${ydh}.[ab]
~/hycom/ALL/archive/src/remap_archv_restep <<E-o-D
${DI}/archv.${ydh}.a
${D}/archv.${ydh}.a
 000	  'iexpt ' = experiment number x10 (000=from archive file)
   3	  'yrflag' = days in year flag (0=360,  1=366,  2=366J1, 3=actual)
 501	  'idm   ' = longitudinal array size
 362	  'jdm   ' = latitudinal  array size
  26	  'kdmold' = original number of layers
  32	  'kdmnew' = target   number of layers
 120	  'itest ' = grid point for debug output
 280	  'jtest ' = grid point for debug output
  32	  'nhybrd' = number of hybrid levels (0=all isopycnal)
  15	  'nsigma' = number of sigma  levels (nhybrd-nsigma z-levels)
   1.0000 'dp0k  ' = layer   0 deep    z-level spacing minimum thickness (m)
   2.0000 'dp0k  ' = layer   1 deep    z-level spacing minimum thickness (m)
   3.5400 'dp0k  ' = layer   2 deep    z-level spacing minimum thickness (m)
   4.1772 'dp0k  ' = layer   3 deep    z-level spacing minimum thickness (m)
   4.9291 'dp0k  ' = layer   4 deep    z-level spacing minimum thickness (m)
   5.8163 'dp0k  ' = layer   5 deep    z-level spacing minimum thickness (m)
   6.8633 'dp0k  ' = layer   6 deep    z-level spacing minimum thickness (m)
   8.0987 'dp0k  ' = layer   7 deep    z-level spacing minimum thickness (m)
   9.5564 'dp0k  ' = layer   8 deep    z-level spacing minimum thickness (m)
  11.2766 'dp0k  ' = layer   9 deep    z-level spacing minimum thickness (m)
  13.3064 'dp0k  ' = layer  10 deep    z-level spacing minimum thickness (m)
  15.7015 'dp0k  ' = layer  11 deep    z-level spacing minimum thickness (m)
  18.5278 'dp0k  ' = layer  12 deep    z-level spacing minimum thickness (m)
  21.8628 'dp0k  ' = layer  13 deep    z-level spacing minimum thickness (m)
  25.7981 'dp0k  ' = layer  14 deep    z-level spacing minimum thickness (m)
  30.4417 'dp0k  ' = layer  15 deep    z-level spacing minimum thickness (m)
  35.9212 'dp0k  ' = layer  16 deep    z-level spacing minimum thickness (m)
  42.3870 'dp0k  ' = layer  17 deep    z-level spacing minimum thickness (m)
  50.0167 'dp0k  ' = layer  18 deep    z-level spacing minimum thickness (m)
  59.0197 'dp0k  ' = layer  19 deep    z-level spacing minimum thickness (m)
  69.6433 'dp0k  ' = layer  20 deep    z-level spacing minimum thickness (m)
  82.1790 'dp0k  ' = layer  21 deep    z-level spacing minimum thickness (m)
  96.9713 'dp0k  ' = layer  22 deep    z-level spacing minimum thickness (m)
 114.4261 'dp0k  ' = layer  23 deep    z-level spacing minimum thickness (m)
 135.0228 'dp0k  ' = layer  24 deep    z-level spacing minimum thickness (m)
 159.3269 'dp0k  ' = layer  25 deep    z-level spacing minimum thickness (m)
 188.0057 'dp0k  ' = layer  26 deep    z-level spacing minimum thickness (m)
 221.8467 'dp0k  ' = layer  27 deep    z-level spacing minimum thickness (m)
 261.7791 'dp0k  ' = layer  28 deep    z-level spacing minimum thickness (m)
 308.8993 'dp0k  ' = layer  29 deep    z-level spacing minimum thickness (m)
 364.5012 'dp0k  ' = layer  30 deep    z-level spacing minimum thickness (m)
 430.1114 'dp0k  ' = layer  31 deep    z-level spacing minimum thickness (m)
   0.1667 'ds0k  ' = layer   0 shallow z-level spacing minimum thickness (m)
   0.3333 'ds0k  ' = layer   1 shallow z-level spacing minimum thickness (m)
   0.5900 'ds0k  ' = layer   2 shallow z-level spacing minimum thickness (m)
   0.6962 'ds0k  ' = layer   3 shallow z-level spacing minimum thickness (m)
   0.8215 'ds0k  ' = layer   4 shallow z-level spacing minimum thickness (m)
   0.9694 'ds0k  ' = layer   5 shallow z-level spacing minimum thickness (m)
   1.1439 'ds0k  ' = layer   6 shallow z-level spacing minimum thickness (m)
   1.3498 'ds0k  ' = layer   7 shallow z-level spacing minimum thickness (m)
   1.5927 'ds0k  ' = layer   8 shallow z-level spacing minimum thickness (m)
   1.8794 'ds0k  ' = layer   9 shallow z-level spacing minimum thickness (m)
   2.2177 'ds0k  ' = layer  10 shallow z-level spacing minimum thickness (m)
   2.6169 'ds0k  ' = layer  11 shallow z-level spacing minimum thickness (m)
   3.0880 'ds0k  ' = layer  12 shallow z-level spacing minimum thickness (m)
   3.6438 'ds0k  ' = layer  13 shallow z-level spacing minimum thickness (m)
   4.2997 'ds0k  ' = layer  14 shallow z-level spacing minimum thickness (m)
  34.0	  'thbase' = reference density (sigma units)
  27.10   'sigma ' = layer  0 isopycnal target density (sigma units)
  28.10   'sigma ' = layer  1 isopycnal target density (sigma units)
  28.90   'sigma ' = layer  2 isopycnal target density (sigma units)
  29.70   'sigma ' = layer  3 isopycnal target density (sigma units)
  30.50   'sigma ' = layer  4 isopycnal target density (sigma units)
  30.95   'sigma ' = layer  5 isopycnal target density (sigma units)
  31.50   'sigma ' = layer  6 isopycnal target density (sigma units)
  32.05   'sigma ' = layer  7 isopycnal target density (sigma units)
  32.60   'sigma ' = layer  8 isopycnal target density (sigma units)
  33.15   'sigma ' = layer  9 isopycnal target density (sigma units)
  33.70   'sigma ' = layer 10 isopycnal target density (sigma units)
  34.25   'sigma ' = layer 11 isopycnal target density (sigma units)
  34.75   'sigma ' = layer 12 isopycnal target density (sigma units)
  35.15   'sigma ' = layer 13 isopycnal target density (sigma units)
  35.50   'sigma ' = layer 14 isopycnal target density (sigma units)
  35.80   'sigma ' = layer 15 isopycnal target density (sigma units)
  36.04   'sigma ' = layer 16 isopycnal target density (sigma units)
  36.20   'sigma ' = layer 17 isopycnal target density (sigma units)
  36.38   'sigma ' = layer 18 isopycnal target density (sigma units)
  36.52   'sigma ' = layer 19 isopycnal target density (sigma units)
  36.62   'sigma ' = layer 20 isopycnal target density (sigma units)
  36.70   'sigma ' = layer 21 isopycnal target density (sigma units)
  36.77   'sigma ' = layer 22 isopycnal target density (sigma units)
  36.83   'sigma ' = layer 23 isopycnal target density (sigma units)
  36.89   'sigma ' = layer 24 isopycnal target density (sigma units)
  36.97   'sigma ' = layer 25 isopycnal target density (sigma units)
  37.02   'sigma ' = layer 26 isopycnal target density (sigma units)
  37.06   'sigma ' = layer 27 isopycnal target density (sigma units)
  37.10   'sigma ' = layer 28 isopycnal target density (sigma units)
  37.17   'sigma ' = layer 29 isopycnal target density (sigma units)
  37.30   'sigma ' = layer 30 isopycnal target density (sigma units)
  37.42   'sigma ' = layer 31 isopycnal target density (sigma units)
E-o-D
      endif
    end
  end
end
#
/bin/rm restart.grid.*
/bbin/rm restart.depth.*
#
date
