#!/bin/csh
#
set echo
#
# --- extract 2-d fields from a single HYCOM archive file.
#
# --- output is netCDF.
# --- this is an example, customize it for your datafile needs.
#
setenv R GOMl0.08
setenv E expt_01.0
setenv T 72
#
touch regional.depth.a regional.depth.b
if (-z regional.depth.a) then
  /bin/rm regional.depth.a
  /bin/ln -s ../topo/depth_${R}_${T}.a regional.depth.a
endif
if (-z regional.depth.b) then
  /bin/rm regional.depth.b
  /bin/ln -s ../topo/depth_${R}_${T}.b regional.depth.b
endif
#
touch regional.grid.a regional.grid.b
if (-z regional.grid.a) then
  /bin/rm regional.grid.a
  /bin/ln -s ../topo/regional.grid.a .
endif
if (-z regional.grid.b) then
  /bin/rm regional.grid.b
  /bin/ln -s ../topo/regional.grid.b .
endif
#
# --- optional title and institution.
#
setenv CDF_TITLE	"HYCOM ${R}"
setenv CDF_INST 	"NOAA/AOML"
#
foreach y ( 2005 )
  setenv DA ~/ARCHIVE/hycom/${R}/${E}/${y}_archives
  setenv DN ~/ARCHIVE/hycom/${R}/${E}/${y}_ascii
  if (! -e ${DN}) then
    /bin/mkdir ${DN}
  endif
foreach d ( 001 )
    foreach h ( 12 )
      ../../ALL/archive/src/archv2data2d <<E-o-D
${DA}/archv.${y}_${d}_${h}.a
(2f10.4,f12.6)
 000	'iexpt ' = experiment number x10 (000=from archive file)
   0	'yrflag' = days in year flag (0=360J16,1=366J16,2=366J01,3-actual)
 271	'idm   ' = longitudinal array size
 193	'jdm   ' = latitudinal  array size
  26	'kdm   ' = number of layers
  25.0	'thbase' = reference density (sigma units)
   1	'smooth' = smooth fields before plotting (0=F,1=T)
   0	'mthin ' = mask thin layers from plots   (0=F,1=T)
   1	'iorign' = i-origin of plotted subregion
   1	'jorign' = j-origin of plotted subregion
   0	'idmp  ' = i-extent of plotted subregion (<=idm; 0 implies idm)
   0	'jdmp  ' = j-extent of plotted subregion (<=jdm; 0 implies jdm)
   0	'botio ' = bathymetry       I/O unit (0 no I/O)
   0	'flxio ' = surf. heat flux  I/O unit (0 no I/O)
   0	'empio ' = surf. evap-pcip  I/O unit (0 no I/O)
   0	'ttrio ' = surf. temp trend I/O unit (0 no I/O)
   0	'strio ' = surf. saln trend I/O unit (0 no I/O)
   0	'icvio ' = ice coverage     I/O unit (0 no I/O)
   0	'ithio ' = ice thickness    I/O unit (0 no I/O)
   0	'ictio ' = ice temperature  I/O unit (0 no I/O)
  23	'sshio ' = sea surf. height I/O unit (0 no I/O)
   0	'bsfio ' = baro. strmfn.    I/O unit (0 no I/O)
   0	'uvmio ' = mix. lay. u-vel. I/O unit (0 no I/O)
   0	'vvmio ' = mix. lay. v-vel. I/O unit (0 no I/O)
   0	'spmio ' = mix. lay. speed  I/O unit (0 no I/O)
   0	'bltio ' = bnd. lay. thick. I/O unit (0 no I/O)
   0	'mltio ' = mix. lay. thick. I/O unit (0 no I/O)
   0	'sstio ' = mix. lay. temp.  I/O unit (0 no I/O)
   0	'sssio ' = mix. lay. saln.  I/O unit (0 no I/O)
   0	'ssdio ' = mix. lay. dens.  I/O unit (0 no I/O)
   0    'h20io ' = 20C isoth. dep.  I/O unit (0 no I/O)
   0    'h26io ' = 26C isoth. dep.  I/O unit (0 no I/O)
   0    'ohcio ' = OHC              I/O unit (0 no I/O)
   1	'kf    ' = first output layer (=0 end output; <0 label with layer #)
   1	'kl    ' = last  output layer
   0  	'uvlio ' = layer k   u-vel. I/O unit (0 no I/O)
   0	'vvlio ' = layer k   v-vel. I/O unit (0 no I/O)
   0	'splio ' = layer k   speed. I/O unit (0 no I/O)
   0    'infio ' = layer k   i.dep. I/O unit (0 no I/O)
   0	'thkio ' = layer k   thick. I/O unit (0 no I/O)
  34	'temio ' = layer k   temp   I/O unit (0 no I/O)
  34	'salio ' = layer k   saln.  I/O unit (0 no I/O)
   0	'tthio ' = layer k   dens,  I/O unit (0 no I/O)
   0	'sfnio ' = layer k  strmfn. I/O unit (0 no I/O)
   0	'kf    ' = first output layer (=0 end output; <0 label with layer #)
E-o-D
      /bin/mv fort.51  ${DN}/topo.${y}_${d}_${h}_2d.txt
      /bin/mv fort.21  ${DN}/sfcflx.${y}_${d}_${h}_2d.txt
      /bin/mv fort.22  ${DN}/ice.${y}_${d}_${h}_2d.txt
      /bin/mv fort.23  ${DN}/ssh.${y}_${d}_${h}_2d.txt
      /bin/mv fort.24  ${DN}/barotp.${y}_${d}_${h}_2d.txt
      /bin/mv fort.25  ${DN}/mxlayr.${y}_${d}_${h}_2d.txt
      /bin/mv fort.26  ${DN}/tc.${y}_${d}_${h}_2d.txt
      /bin/mv fort.31  ${DN}/vel.${y}_${d}_${h}_layer1.txt
      /bin/mv fort.32  ${DN}/intf.${y}_${d}_${h}_layer1.txt
      /bin/mv fort.33  ${DN}/thknss.${y}_${d}_${h}_layer1.txt
      /bin/mv fort.34  ${DN}/thermo.${y}_${d}_${h}_layer1.txt
      /bin/mv fort.35  ${DN}/strmf.${y}_${d}_${h}_layer1.txt
    end
  end
end
