#! /bin/csh
#BSUB -n 1
#BSUB -W 24:00
set echo
#
# --- form the mean and mean-square of a sequence of archive files
#
# --- R is region name.
# --- T is topography number.
# --- K is number of layers (or 1 for a surface mean).
# --- E is expt number.
# --- P is primary path.
# --- D is permanent directory.
# --- S is scratch   directory, can be the permanent directory.
#
setenv R WFSa0.04
setenv T 06
setenv K 22
setenv E 011
setenv P ${R}/expt_01.1/data
setenv D ../../$P
setenv S ../../${R}/scratch
#
# --- pget, pput "copy" files between scratch and permanent storage.
#
setenv pget "/bin/ln -s"
setenv pput "/bin/cp"
#
mkdir -p  ${S}
cd        ${S}
#
touch   regional.depth.a regional.depth.b
/bin/rm regional.depth.a regional.depth.b
ln -s ${D}/../../topo/depth_${R}_${T}.a regional.depth.a
ln -s ${D}/../../topo/depth_${R}_${T}.b regional.depth.b
#
touch regional.grid.a regional.grid.b
if (-z regional.grid.a) then
  /bin/rm regional.grid.a
  /bin/ln -s ${D}/../../topo/regional.grid.a regional.grid.a
endif
if (-z regional.grid.b) then
  /bin/rm regional.grid.b
  /bin/ln -s ${D}/../../topo/regional.grid.b regional.grid.b
endif
#
# --- WFS archive files.
#
touch ${E}_mean.tmp
foreach year ( 0010 )
  foreach day ( 039 040 041 042 043 044 045 046 047 048 049 )
    foreach hour ( 00 )
#
      ${pget} ${D}/${E}_archv.${year}_${day}_${hour}.a archv.${year}_${day}_${hour}.a &
      ${pget} ${D}/${E}_archv.${year}_${day}_${hour}.b archv.${year}_${day}_${hour}.b &
#
      echo "${year}_${day}_${hour}" >> ${E}_mean.tmp
#
    end
  end
end
wait
#
# --- mean.
#
setenv NA `cat ${E}_mean.tmp | wc -l`
echo "  $K	'kk    ' = number of layers involved"               >! ${E}_mean.IN
echo "  0	'meansq' = form meansq, rather than mean (0=F,1=T)" >> ${E}_mean.IN
echo "  $NA	'narchs' = number of archives to read (==0 to end input)" >> ${E}_mean.IN
cat ${E}_mean.tmp | awk '{printf("archv.%s.a\n",$1)}' >> ${E}_mean.IN
echo "  0  	'narchs' = number of archives to read (==0 to end input)" >> ${E}_mean.IN
echo   "archMN.${year}" >> ${E}_mean.IN
touch   archMN.${year}.a archMN.${year}.b
/bin/rm archMN.${year}.a archMN.${year}.b
cat ${E}_mean.IN
${D}/../../../ALL/meanstd/src/hycom_mean < ${E}_mean.IN
cat ${E}_mean.IN
if ($D != $S) then
  ${pput} archMN.${year}.a ${D}/archMN.${year}.a
  ${pput} archMN.${year}.b ${D}/archMN.${year}.b
endif
#
# --- mnsq.
#
#  sed -e "s/0	'meansq'/1	'meansq'/g" -e "s/archMN/archSQ/g" ${E}_mean.IN >! ${E}_mnsq.IN
#  touch   archSQ.${Y}${mon}.a archSQ.${Y}${mon}.b
#  /bin/rm archSQ.${Y}${mon}.a archSQ.${Y}${mon}.b
#  cat ${E}_mnsq.IN
#  ${D}/../../../ALL/meanstd/src/hycom_mean < ${E}_mnsq.IN
#  cat ${E}_mnsq.IN
#  if ($D != $S) then
#    ${pput} archSQ.${Y}.a ${D}/archSQ.${Y}.a
#    ${pput} archSQ.${Y}.b ${D}/archSQ.${Y}.b
#  endif
#
# /bin/rm ${E}_mean.IN ${E}_mnsq.IN ${E}_mean.tmp
#end
