#!/bin/csh
#PBS -N subregion
#PBS -A ocean-osse
#PBS -d .
#PBS -q bigmem
#PBS -o subregion.out
#PBS -e subregion.err
#PBS -l walltime=0:30:0
#PBS -l procs=1
#PBS -l vmem=2000M
#
set echo
set time=1
#
# --- form interpolated subregion archive files, ATLo0.08 to HAT20.08.
#
# --- script includes logic to reduce the number of layers,
# --- but it is inactivated here by setting L to "".
#
# --- ALL/bin/hycom_ij2lonlat can be used to find co-located points
# ---  on the two grids.  Since subregion p(1,1) must be on the
# ---  original grid, this is usually the point to reference.
# --- In the 2-degree Atlantic case:
# ---   hycom_ij2lonlat 1 1  ~/hycom/IASb0.50/topo/regional.grid.a
# ---    97.000W   3.997N
# ---   hycom_ij2lonlat 1 13 ~/hycom/ATLb2.00/topo/regional.grid.a
# ---    97.000W   3.997N
#
setenv R1 ATLo0.08
setenv R2 HAT20.08
setenv EXP1 expt_03.0
setenv EXP2 expt_01.0
setenv DT ../../${R1}/topo
setenv RT ../topo
setenv T1 10
setenv T2 02
#
# --- single model segment, potentially across multiple calendar years.
# --- configured for  1-day surface and 3-d archives.
#
foreach y ( 2009 )
  setenv D  ~/s4/hycom/${R1}/${EXP1}/data/archv_${y}
  setenv R  ~/s4/hycom/${R2}/${EXP2}/data/archv_fm
  if (! -e ${R}) then
    /bin/mkdir ${R}
  endif
  foreach d ( 240 )
    foreach h ( 00 )
      setenv ydh  ${y}_${d}_${h}
      setenv ydh0 ${y}_${d}_00
      if (-e ${D}/archv.${ydh}.b) then
        if (! -e regional.grid.a) then
          /bin/ln -s ${DT}/regional.grid.a regional.grid.a
          /bin/ln -s ${DT}/regional.grid.b regional.grid.b
        endif
        touch   ${R}/archv.${ydh}.b
        /bin/rm ${R}/archv.${ydh}.[ab]
        ~/hycom/ALL/subregion/src/isubregion <<E-o-D
${D}/archv.${ydh}.b
${DT}/depth_${R1}_${T1}.b
${R}/archv.${ydh}.b
${RT}/depth_${R2}_${T2}.b
${R1}interpolated to ${R2}
 501      'idm   ' = longitudinal array size
 362      'jdm   ' = latitudinal  array size
 313      'irefi ' = longitudinal input  reference location
 136      'jrefi ' = latitudinal  input  reference location
   1      'irefo ' = longitudinal output reference location
   1      'jrefo ' = latitudinal  output reference location 
   1      'ijgrd ' = integer scale factor between input and output grids
   0      'iceflg' = ice in output archive flag (0=none,1=energy loan model)
   0      'smooth' = smooth interface depths    (0=F,1=T)
E-o-D
#
        touch    ${R}/archv.${ydh}.b
        if (-z ${R}/archv.${ydh}.b) then
          echo "missing archive file: " ${R}/archv.${ydh}.b
          exit (2)
        endif
#
      endif
    end
  end
#
end
